@@ -27,3 +27,6 @@ from lightly_studio.models.settings import (
 from lightly_studio.models.tag import (
     TagTable,  # noqa: F401, required for SQLModel to work properly
 )
+from lightly_studio.models.two_dim_embedding import (
+    TwoDimEmbeddingTable,  # noqa: F401, required for SQLModel to work properly
+)
