@@ -6,6 +6,7 @@ from pathlib import Path
 from typing import Iterable, Iterator
 from uuid import UUID
 
+import yaml
 from labelformat.formats import (
     COCOInstanceSegmentationInput,
     COCOObjectDetectionInput,
@@ -37,12 +38,15 @@ from lightly_studio.models.sample import SampleTable
 from lightly_studio.resolvers import (
     dataset_resolver,
     embedding_model_resolver,
+    sample_embedding_resolver,
     sample_resolver,
+    tag_resolver,
 )
 from lightly_studio.type_definitions import PathLike
 
 # Constants
 DEFAULT_DATASET_NAME = "default_dataset"
+ALLOWED_YOLO_SPLITS = {"train", "val", "test", "minival"}
 
 _SliceType = slice  # to avoid shadowing built-in slice in type annotations
 
@@ -50,7 +54,40 @@ _SliceType = slice  # to avoid shadowing built-in slice in type annotations
 class Dataset:
     """A LightlyStudio Dataset.
 
-    Keeps a reference to the underlying DatasetTable.
+    It can be created or loaded using one of the static methods:
+    ```python
+    dataset = Dataset.create()
+    dataset = Dataset.load()
+    dataset = Dataset.load_or_create()
+    ```
+
+    Samples can be added to the dataset using various methods:
+    ```python
+    dataset.add_samples_from_path(...)
+    dataset.add_samples_from_yolo(...)
+    dataset.add_samples_from_coco(...)
+    dataset.add_samples_from_coco_caption(...)
+    dataset.add_samples_from_labelformat(...)
+    ```
+
+    The dataset samples can be queried directly by iterating over it or slicing it:
+    ```python
+    dataset = Dataset.load("my_dataset")
+    first_ten_samples = dataset[:10]
+    for sample in dataset:
+        print(sample.file_name)
+        sample.metadata["new_key"] = "new_value"
+    ```
+
+    For filtering or ordering samples first, use the query interface:
+    ```python
+    from lightly_studio.core.dataset_query.sample_field import SampleField
+
+    dataset = Dataset.load("my_dataset")
+    query = dataset.match(SampleField.width > 10).order_by(SampleField.file_name)
+    for sample in query:
+        ...
+    ```
     """
 
     def __init__(self, dataset: DatasetTable) -> None:
@@ -68,7 +105,7 @@ class Dataset:
 
         dataset = dataset_resolver.create(
             session=db_manager.persistent_session(),
-            dataset=DatasetCreate(name=name, directory=""),
+            dataset=DatasetCreate(name=name),
         )
         return Dataset(dataset=dataset)
 
@@ -81,7 +118,10 @@ class Dataset:
         dataset = dataset_resolver.get_by_name(session=db_manager.persistent_session(), name=name)
         if dataset is None:
             raise ValueError(f"Dataset with name '{name}' not found.")
-
+        # If we have embeddings in the database enable the FSC and embedding search features.
+        _enable_embedding_features_if_available(
+            session=db_manager.persistent_session(), dataset_id=dataset.dataset_id
+        )
         return Dataset(dataset=dataset)
 
     @staticmethod
@@ -94,6 +134,10 @@ class Dataset:
         if dataset is None:
             return Dataset.create(name=name)
 
+        # If we have embeddings in the database enable the FSC and embedding search features.
+        _enable_embedding_features_if_available(
+            session=db_manager.persistent_session(), dataset_id=dataset.dataset_id
+        )
         return Dataset(dataset=dataset)
 
     def __iter__(self) -> Iterator[Sample]:
@@ -262,14 +306,15 @@ class Dataset:
     def add_samples_from_yolo(
         self,
         data_yaml: PathLike,
-        input_split: str = "train",
+        input_split: str | None = None,
         embed: bool = True,
     ) -> None:
         """Load a dataset in YOLO format and store in DB.
 
         Args:
             data_yaml: Path to the YOLO data.yaml file.
-            input_split: The split to load (e.g., 'train', 'val').
+            input_split: The split to load (e.g., 'train', 'val', 'test').
+                If None, all available splits will be loaded and assigned a corresponding tag.
             embed: If True, generate embeddings for the newly added samples.
         """
         if isinstance(data_yaml, str):
@@ -279,24 +324,54 @@ class Dataset:
         if not data_yaml.is_file() or data_yaml.suffix != ".yaml":
             raise FileNotFoundError(f"YOLO data yaml file not found: '{data_yaml}'")
 
-        # Load the dataset using labelformat.
-        label_input = YOLOv8ObjectDetectionInput(
-            input_file=data_yaml,
-            input_split=input_split,
-        )
-        images_path = label_input._images_dir()  # noqa: SLF001
+        # Determine which splits to process
+        splits_to_process = _resolve_yolo_splits(data_yaml=data_yaml, input_split=input_split)
 
-        self.add_samples_from_labelformat(
-            input_labels=label_input,
-            images_path=images_path,
-            embed=embed,
-        )
+        all_created_sample_ids = []
+
+        # Process each split
+        for split in splits_to_process:
+            # Load the dataset using labelformat.
+            label_input = YOLOv8ObjectDetectionInput(
+                input_file=data_yaml,
+                input_split=split,
+            )
+            images_path = label_input._images_dir()  # noqa: SLF001
+
+            created_sample_ids = add_samples.load_into_dataset_from_labelformat(
+                session=self.session,
+                dataset_id=self.dataset_id,
+                input_labels=label_input,
+                images_path=images_path,
+            )
+
+            # Tag samples with split name
+            if created_sample_ids:
+                tag = tag_resolver.get_or_create_sample_tag_by_name(
+                    session=self.session,
+                    dataset_id=self.dataset_id,
+                    tag_name=split,
+                )
+                tag_resolver.add_sample_ids_to_tag_id(
+                    session=self.session,
+                    tag_id=tag.tag_id,
+                    sample_ids=created_sample_ids,
+                )
+
+            all_created_sample_ids.extend(created_sample_ids)
+
+        # Generate embeddings for all samples at once
+        if embed:
+            _generate_embeddings(
+                session=self.session, dataset_id=self.dataset_id, sample_ids=all_created_sample_ids
+            )
 
     def add_samples_from_coco(
         self,
         annotations_json: PathLike,
         images_path: PathLike,
         annotation_type: AnnotationType = AnnotationType.OBJECT_DETECTION,
+        split: str | None = None,
         embed: bool = True,
     ) -> None:
         """Load a dataset in COCO Object Detection format and store in DB.
@@ -306,6 +381,8 @@ class Dataset:
             images_path: Path to the folder containing the images.
             annotation_type: The type of annotation to be loaded (e.g., 'ObjectDetection',
                 'InstanceSegmentation').
+            split: Optional split name to tag samples (e.g., 'train', 'val').
+                If provided, all samples will be tagged with this name.
             embed: If True, generate embeddings for the newly added samples.
         """
         if isinstance(annotations_json, str):
@@ -330,12 +407,83 @@ class Dataset:
 
         images_path = Path(images_path).absolute()
 
-        self.add_samples_from_labelformat(
+        created_sample_ids = add_samples.load_into_dataset_from_labelformat(
+            session=self.session,
+            dataset_id=self.dataset_id,
             input_labels=label_input,
             images_path=images_path,
-            embed=embed,
         )
 
+        # Tag samples with split name if provided
+        if split is not None and created_sample_ids:
+            tag = tag_resolver.get_or_create_sample_tag_by_name(
+                session=self.session,
+                dataset_id=self.dataset_id,
+                tag_name=split,
+            )
+            tag_resolver.add_sample_ids_to_tag_id(
+                session=self.session,
+                tag_id=tag.tag_id,
+                sample_ids=created_sample_ids,
+            )
+
+        if embed:
+            _generate_embeddings(
+                session=self.session, dataset_id=self.dataset_id, sample_ids=created_sample_ids
+            )
+
+    def add_samples_from_coco_caption(
+        self,
+        annotations_json: PathLike,
+        images_path: PathLike,
+        split: str | None = None,
+        embed: bool = True,
+    ) -> None:
+        """Load a dataset in COCO caption format and store in DB.
+
+        Args:
+            annotations_json: Path to the COCO caption JSON file.
+            images_path: Path to the folder containing the images.
+            split: Optional split name to tag samples (e.g., 'train', 'val').
+                If provided, all samples will be tagged with this name.
+            embed: If True, generate embeddings for the newly added samples.
+        """
+        if isinstance(annotations_json, str):
+            annotations_json = Path(annotations_json)
+        annotations_json = annotations_json.absolute()
+
+        if not annotations_json.is_file() or annotations_json.suffix != ".json":
+            raise FileNotFoundError(f"COCO caption json file not found: '{annotations_json}'")
+
+        if isinstance(images_path, str):
+            images_path = Path(images_path)
+        images_path = images_path.absolute()
+
+        created_sample_ids = add_samples.load_into_dataset_from_coco_captions(
+            session=self.session,
+            dataset_id=self.dataset_id,
+            annotations_json=annotations_json,
+            images_path=images_path,
+        )
+
+        # Tag samples with split name if provided
+        if split is not None and created_sample_ids:
+            tag = tag_resolver.get_or_create_sample_tag_by_name(
+                session=self.session,
+                dataset_id=self.dataset_id,
+                tag_name=split,
+            )
+            tag_resolver.add_sample_ids_to_tag_id(
+                session=self.session,
+                tag_id=tag.tag_id,
+                sample_ids=created_sample_ids,
+            )
+
+        if embed:
+            _generate_embeddings(
+                session=self.session, dataset_id=self.dataset_id, sample_ids=created_sample_ids
+            )
+
     def compute_typicality_metadata(
         self,
         embedding_model_name: str | None = None,
@@ -393,3 +541,69 @@ def _generate_embeddings(session: Session, dataset_id: UUID, sample_ids: list[UU
     # Mark the embedding search feature as enabled.
     if "embeddingSearchEnabled" not in features.lightly_studio_active_features:
         features.lightly_studio_active_features.append("embeddingSearchEnabled")
+    # Mark the FSC feature as enabled.
+    if "fewShotClassifierEnabled" not in features.lightly_studio_active_features:
+        features.lightly_studio_active_features.append("fewShotClassifierEnabled")
+
+
+def _resolve_yolo_splits(data_yaml: Path, input_split: str | None) -> list[str]:
+    """Determine which YOLO splits to process for the given config."""
+    if input_split is not None:
+        if input_split not in ALLOWED_YOLO_SPLITS:
+            raise ValueError(
+                f"Split '{input_split}' not found in config file '{data_yaml}'. "
+                f"Allowed splits: {sorted(ALLOWED_YOLO_SPLITS)}"
+            )
+        return [input_split]
+
+    with data_yaml.open() as f:
+        config = yaml.safe_load(f)
+
+    config_keys = config.keys() if isinstance(config, dict) else []
+    splits = [key for key in config_keys if key in ALLOWED_YOLO_SPLITS]
+    if not splits:
+        raise ValueError(f"No splits found in config file '{data_yaml}'")
+    return splits
+
+
+def _are_embeddings_available(session: Session, dataset_id: UUID) -> bool:
+    """Check if there are any embeddings available for the given dataset.
+
+    Args:
+        session: Database session for resolver operations.
+        dataset_id: The ID of the dataset to check for embeddings.
+
+    Returns:
+        True if embeddings exist for the dataset, False otherwise.
+    """
+    embedding_manager = EmbeddingManagerProvider.get_embedding_manager()
+    model_id = embedding_manager.load_or_get_default_model(
+        session=session,
+        dataset_id=dataset_id,
+    )
+    if model_id is None:
+        # No default embedding model loaded for this dataset.
+        return False
+
+    return (
+        len(
+            sample_embedding_resolver.get_all_by_dataset_id(
+                session=session, dataset_id=dataset_id, embedding_model_id=model_id
+            )
+        )
+        > 0
+    )
+
+
+def _enable_embedding_features_if_available(session: Session, dataset_id: UUID) -> None:
+    """Enable embedding-related features if embeddings are available in the DB.
+
+    Args:
+        session: Database session for resolver operations.
+        dataset_id: The ID of the dataset to check for embeddings.
+    """
+    if _are_embeddings_available(session=session, dataset_id=dataset_id):
+        if "embeddingSearchEnabled" not in features.lightly_studio_active_features:
+            features.lightly_studio_active_features.append("embeddingSearchEnabled")
+        if "fewShotClassifierEnabled" not in features.lightly_studio_active_features:
+            features.lightly_studio_active_features.append("fewShotClassifierEnabled")
