@@ -16,8 +16,17 @@ from lightly_studio.models.sample import SampleTable
 class SampleField:
     """Providing access to predefined sample fields for queries.
 
-    This class provides static instances of different field types that can be
-    used to build database queries on sample properties.
+    It is used for the `query.match(...)` and `query.order_by(...)` methods of the
+    `DatasetQuery` class.
+
+    ```python
+    from lightly_studio.core.dataset_query import DatasetQuery, SampleField, OrderByField
+
+    query = dataset.query()
+    query.match(SampleField.tags.contains("cat"))
+    query.order_by(OrderByField(SampleField.file_path_abs))
+    samples = query.to_list()
+    ```
     """
 
     file_name = StringField(col(SampleTable.file_name))
