@@ -5,11 +5,15 @@ from pathlib import Path
 from environs import Env
 
 import lightly_studio as ls
+from lightly_studio import db_manager
 
 # Read environment variables
 env = Env()
 env.read_env()
 
+# Cleanup an existing database
+db_manager.connect(cleanup_existing=True)
+
 # Define the path to the dataset directory
 dataset_path = Path(env.path("DATASET_PATH", "/path/to/your/dataset"))
 dataset_path = dataset_path.parent if dataset_path.is_file() else dataset_path
