@@ -1,6 +1,10 @@
 """Example of how to add samples in coco format to a dataset."""
 
 import lightly_studio as ls
+from lightly_studio import db_manager
+
+# Cleanup an existing database
+db_manager.connect(cleanup_existing=True)
 
 # Create a DatasetLoader from a path
 dataset = ls.Dataset.create()
