@@ -5,11 +5,15 @@ import math
 from environs import Env
 
 import lightly_studio as ls
+from lightly_studio import db_manager
 
 # Read environment variables
 env = Env()
 env.read_env()
 
+# Cleanup an existing database
+db_manager.connect(cleanup_existing=True)
+
 # Create a Dataset instance
 dataset = ls.Dataset.create()
 
