@@ -1,14 +1,14 @@
 """Metadata resolver module."""
 
 from lightly_studio.resolvers.metadata_resolver.sample import (
-    bulk_set_metadata,
+    bulk_update_metadata,
     get_by_sample_id,
     get_value_for_sample,
     set_value_for_sample,
 )
 
 __all__ = [
-    "bulk_set_metadata",
+    "bulk_update_metadata",
     "get_by_sample_id",
     "get_value_for_sample",
     "set_value_for_sample",
