@@ -1,7 +1,7 @@
 """Resolvers for metadata operations."""
 
-from .bulk_set_metadata import (
-    bulk_set_metadata,
+from .bulk_update_metadata import (
+    bulk_update_metadata,
 )
 from .get_by_sample_id import (
     get_by_sample_id,
@@ -14,7 +14,7 @@ from .set_value_for_sample import (
 )
 
 __all__ = [
-    "bulk_set_metadata",
+    "bulk_update_metadata",
     "get_by_sample_id",
     "get_value_for_sample",
     "set_value_for_sample",
