@@ -2,6 +2,7 @@
 
 from pathlib import Path
 from typing import TypeVar, Union
+from uuid import UUID
 
 from sqlmodel.sql.expression import SelectOfScalar
 
@@ -14,6 +15,7 @@ QueryType = TypeVar(
     SelectOfScalar[AnnotationBaseTable],
     SelectOfScalar[SampleTable],
     SelectOfScalar[int],
+    SelectOfScalar[UUID],
 )
 
 PathLike = Union[str, Path]
